@@ -143,6 +143,8 @@ def deploy_function(
         if function.status == 'Ready':
             break
         if function.status == 'Failed' and trial < max_errors-1:
+            logging.warning(f"Function failed: {function.id=}")
+            logging.debug(f"Error was: {function.error=}")
             logging.debug(f"Try to create function again")
         else:
             raise Exception(f"Function deployment error: {function.error=}")
@@ -363,7 +365,8 @@ def find_model_version(model_name, env, metadata):
         limit=-1, 
         directory_prefix='/mlops', 
         external_id_prefix=f"{model_name}/{env}",
-        metadata=metadata
+        metadata=metadata,
+        uploaded=True
     ).to_pandas()
 
     if (n_models := file_list.shape[0]) == 0:
