@@ -24,6 +24,7 @@ LOCAL_DEPLOYMENT = os.getenv('LOCAL_DEPLOYMENT') # Optional
 
 
 def deploy(model_settings):
+    failed_models = {}
     for setting in model_settings:
         try:
             (model_name, model_file, model_req_file, model_artifact_folder,
@@ -143,9 +144,10 @@ def deploy(model_settings):
                                     "End-to-end test skipped!")
         except Exception as error:
             error_type = type(error).__name__
-            error_message = f" Training service failed. {error_type}: {error}"
+            error_message = f"Training service failed.\n{error_type}\n{error}"
             logging.error(error_message)
             logging.warning("Model failed to deploy!")
+            failed_models[model_name] = error_message
 
         finally:
             logging.debug(f"cd ..")
@@ -155,6 +157,11 @@ def deploy(model_settings):
             if os.path.isdir(deployment_folder):
                 shutil.rmtree(deployment_folder)
 
+    if failed_models:
+        for model_name, error_message in failed_models.items():
+            logging.info(f"Model {model_name} failed: {error_message}")
+        raise Exception("At least one model failed.")
+
 
 if __name__ == '__main__':
     set_up_cdf_client(context='deploy')
